from setuptools import setup



setup(
    name="lequangminh",
    version='0.0.1',
    license='Eclipse Public License 0.0.1',
    authors=["quangminh591", "loTus01", "BlueRed"],
    author_email="<quangminh591@gmail.com>",
    description="by quangminh591, loTus01 and BlueRed",
    keywords=['cli', 'fade', 'colors', 'terminal', 'tui'],
    packages=['lequangminh']
)
